DistAPIBase
===========

.. currentmodule:: atqo

.. autoclass:: DistAPIBase
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~DistAPIBase.exception

   .. rubric:: Methods Summary

   .. autosummary::

      ~DistAPIBase.get_future
      ~DistAPIBase.get_running_actor
      ~DistAPIBase.join
      ~DistAPIBase.kill
      ~DistAPIBase.parse_exception

   .. rubric:: Attributes Documentation

   .. autoattribute:: exception

   .. rubric:: Methods Documentation

   .. automethod:: get_future
   .. automethod:: get_running_actor
   .. automethod:: join
   .. automethod:: kill
   .. automethod:: parse_exception
